==> estateplat-common-1.1.0-20160726.011606-129-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsXm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡项目
 */
@Table(name = "gd_ls_xm")
public class GdLsXm {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 初审人
     */
    private String csr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 审核人
     */
    private String shr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 更新日期
     */
    private Date gxrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 不动产类型
     */
    private String bdclx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 匹配状态
     */
    private String ppzt;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记类型
     */
    private String djlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 受理编号
     */
    private String slbh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 单位代码
     */
    private String dwdm;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 原项目ID
     */
    private String yproid;

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getYproid() {
        return yproid;
    }

    public void setYproid(String yproid) {
        this.yproid = yproid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCsr() {
        return csr;
    }

    public void setCsr(String csr) {
        this.csr = csr;
    }

    public String getShr() {
        return shr;
    }

    public void setShr(String shr) {
        this.shr = shr;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getPpzt() {
        return ppzt;
    }

    public void setPpzt(String ppzt) {
        this.ppzt = ppzt;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }


}

==> estateplat-common-1.2.4-20211012.063434-910-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsXm.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡项目
 */
@Table(name = "gd_ls_xm")
public class GdLsXm {
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 创建日期
     */
    private Date cjrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 不动产类型
     */
    private String bdclx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记类型
     */
    private String djlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 受理编号
     */
    private String slbh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 单位代码
     */
    private String dwdm;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登记机构
     */
    private String djjg;

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public Date getCjrq() {
        return cjrq;
    }

    public void setCjrq(Date cjrq) {
        this.cjrq = cjrq;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }
}
